@@ -10,7 +10,9 @@
 
 #include "gnome-cd.h"
 
-void cddb_get_query (GnomeCD *gcd);
-int cddb_sum (int n);
+void cddb_get_query      (GnomeCD *gcd);
+int  cddb_sum            (int n);
+void cddb_close_client   (void);
+void cddb_free_disc_info (GnomeCDDiscInfo *info);
 
 #endif
