@@ -23,6 +23,7 @@
 #include "config.h"
 #endif
 
+#include <glib/gi18n.h>
 #include <gnome.h>
 #include <gtk/gtk.h>
 
@@ -30,6 +31,7 @@
 #include "keys.h"
 #include "preferences.h"
 #include "track.h"
+#include "misc.h"
 
 static void	gnome_volume_control_element_class_init	(GnomeVolumeControlElementClass *klass);
 static void	gnome_volume_control_element_init	(GnomeVolumeControlElement *el);
@@ -123,6 +125,9 @@ gnome_volume_control_element_dispose (GObject *object)
   }
 
   if (el->mixer) {
+    /* remove g_timeout_add() mainloop handlers */
+    gnome_volume_control_element_change (el, NULL);
+    gst_element_set_state (GST_ELEMENT (el->mixer), GST_STATE_NULL);
     gst_object_unref (GST_OBJECT (el->mixer));
     el->mixer = NULL;
   }
@@ -142,13 +147,16 @@ gnome_volume_control_element_whitelist (GstMixerTrack *track,
   gboolean found = FALSE;
 
   for (i = 0; !found && list[i].label != NULL; i++) {
-    gchar *label_l;
+    gchar *label_l = NULL;
 
     if (list[i].done)
       continue;
 
     /* make case insensitive */
-    label_l = g_strdup (track->label);
+    if (g_object_class_find_property (G_OBJECT_GET_CLASS (track), "untranslated-label"))
+      g_object_get (track, "untranslated-label", &label_l, NULL);
+    if (label_l == NULL)
+      g_object_get (track, "label", &label_l, NULL);
     for (pos = 0; label_l[pos] != '\0'; pos++)
       label_l[pos] = g_ascii_tolower (label_l[pos]);
 
@@ -166,19 +174,6 @@ gnome_volume_control_element_whitelist (GstMixerTrack *track,
  * Hide/show notebook page.
  */
 
-static gint
-get_page_num (GstMixerTrack *track)
-{
-  if (GST_IS_MIXER_OPTIONS (track))
-    return 3;
-  else if (track->num_channels == 0)
-    return 2;
-  else if (track->flags & GST_MIXER_TRACK_INPUT)
-    return 1;
-  else
-    return 0;
-}
-
 static void
 update_tab_visibility (GnomeVolumeControlElement *el, gint page)
 {
@@ -240,9 +235,6 @@ gnome_volume_control_element_change (GnomeVolumeControlElement *el,
   const GList *item;
   GstMixer *mixer;
 
-  g_return_if_fail (GST_IS_MIXER (element));
-  mixer = GST_MIXER (element);
-
   /* remove old pages */
   while (gtk_notebook_get_n_pages (GTK_NOTEBOOK (el)) > 0) {
     gtk_notebook_remove_page (GTK_NOTEBOOK (el), 0);
@@ -260,6 +252,11 @@ gnome_volume_control_element_change (GnomeVolumeControlElement *el,
       gnome_volume_control_track_free (trkw);
     }
   }
+  if (!element)
+    return;
+
+  g_return_if_fail (GST_IS_MIXER (element));
+  mixer = GST_MIXER (element);
   gst_object_replace ((GstObject **) &el->mixer, GST_OBJECT (element));
 
   /* content pages */
