@@ -23,6 +23,7 @@
 #include "config.h"
 #endif
 
+#include <glib/gi18n.h>
 #include <gnome.h>
 #include <string.h>
 
@@ -105,16 +106,12 @@ cb_option_changed (GtkComboBox *box,
 		   gpointer     data)
 {
   GnomeVolumeControlTrack *ctrl = data;
-  GtkTreeIter iter;
-  GtkTreeModel *model;
   gchar *opt;
 
-  if (gtk_combo_box_get_active_iter (box, &iter)) {
-    model = gtk_combo_box_get_model (box);
-    gtk_tree_model_get (model, &iter, 0, &opt, -1);
+  opt = gtk_combo_box_get_active_text (box);
+  if (opt)
     gst_mixer_set_option (ctrl->mixer, GST_MIXER_OPTIONS (ctrl->track), opt);
-    g_free (opt);
-  }
+  g_free (opt);
 }
 
 /*
@@ -130,8 +127,8 @@ cb_check (gpointer data)
 
   /* trigger an update of the mixer state */
   if (!GST_IS_MIXER_OPTIONS (trkw->track)) {
-    gint *dummy = g_new (gint, GST_MIXER_TRACK (trkw->track)->num_channels);
-    gst_mixer_get_volume (trkw->mixer, GST_MIXER_TRACK (trkw->track), dummy);
+    gint *dummy = g_new (gint, MAX (trkw->track->num_channels, 1));
+    gst_mixer_get_volume (trkw->mixer, trkw->track, dummy);
     g_free (dummy);
   }
   
@@ -191,8 +188,8 @@ gnome_volume_control_track_add_title (GtkTable *table,
 				      GtkWidget *r_sep)
 {
   GnomeVolumeControlTrack *ctrl;
+  gchar *ulabel = NULL;
   gchar *str = NULL;
-  gboolean found = FALSE;
   gint i;
 
   /* start */
@@ -207,22 +204,28 @@ gnome_volume_control_track_add_title (GtkTable *table,
   ctrl->pos = tab_pos;
   ctrl->id = g_timeout_add (200, cb_check, ctrl);
 
-  /* image (optional) */
-  for (i = 0; !found && pix[i].label != NULL; i++) {
-    /* we dup the string to make the comparison case-insensitive */
-    gchar *label_l = g_strdup (track->label);
+  /* find image from label string (optional) */
+  if (g_object_class_find_property (G_OBJECT_GET_CLASS (track), "untranslated-label"))
+    g_object_get (track, "untranslated-label", &ulabel, NULL);
+
+  if (ulabel == NULL)
+    g_object_get (track, "label", &ulabel, NULL);
+
+  if (ulabel) {
     gint pos;
 
     /* make case insensitive */
-    for (pos = 0; label_l[pos] != '\0'; pos++)
-      label_l[pos] = g_ascii_tolower (label_l[pos]);
+    for (pos = 0; ulabel[pos] != '\0'; pos++)
+      ulabel[pos] = g_ascii_tolower (ulabel[pos]);
 
-    if (g_strrstr (label_l, pix[i].label) != NULL) {
-      str = pix[i].pixmap;
-      found = TRUE;
+    for (i = 0; pix[i].label != NULL; i++) {
+      if (g_strrstr (ulabel, pix[i].label) != NULL) {
+        str = pix[i].pixmap;
+        break;
+      }
     }
 
-    g_free (label_l);
+    g_free (ulabel);
   }
 
   if (str != NULL) {
@@ -245,7 +248,7 @@ gnome_volume_control_track_add_title (GtkTable *table,
   if (or == GTK_ORIENTATION_HORIZONTAL)
     str = g_strdup_printf (_("%s:"), track->label);
   else
-    str = track->label;
+    str = g_strdup (track->label);
   ctrl->label = gtk_label_new (str);
   if (or == GTK_ORIENTATION_HORIZONTAL) {
     g_free (str);
